@@ -1,6 +1,6 @@
 package Getopt::EX::Func;
 
-our $VERSION = "3.01";
+our $VERSION = "3.02";
 
 use v5.14;
 use warnings;
@@ -68,6 +68,12 @@ sub closure {
 ##
 my $paren_re = qr/( \( (?: [^()]++ | (?-1) )*+ \) )/x;
 
+##
+## Key name pattern for function arguments.
+## Should be \w+ but currently allows more characters for historical reasons.
+##
+my $key_re = qr/[^,=*\/]+/;
+
 sub parse_func {
     my $opt = ref $_[0] eq 'HASH' ? shift : {};
     local $_ = shift;
@@ -103,32 +109,24 @@ sub parse_func {
 
 ##
 ## convert "key1,key2,key3=val3" to (key1=>1, key2=>1, key3=>"val3")
-## use ~ instead of = to take the rest of the string as a value
-## e.g., "key1,key2~a,b,c" => (key1=>1, key2=>"a,b,c")
+##
+## *= takes the rest of the string as a value
+## e.g., "key1,key2*=a,b,c" => (key1=>1, key2=>"a,b,c")
+##
+## /= uses the next character as a delimiter
+## e.g., "key1,key2/=/a,b,c/,next" => (key1=>1, key2=>"a,b,c", next=>1)
 ##
 sub arg2kvlist {
     my @kv;
     for (@_) {
-	while (/\G \s*
-	       (?<k> [\w\-.]+ )
-	       (?:
-		   ~ (?<rest> .* )
-		 |
-		   (?: = (?<v> (?: [^,()]++ | ${paren_re} )*+ ) )?
-	       )
-	       ,*/xgc
-	    ) {
-	    if (defined $+{rest}) {
-		push @kv, ( $+{k}, $+{rest} );
-		last;
-	    } else {
-		push @kv, ( $+{k}, $+{v} // 1 );
-	    }
-	}
-	my $pos = pos() // 0;
-	if ($pos != length) {
-	    die "parse error in \"$_\".\n";
+	while (/\G \s* (?<key>(?>${key_re}))
+	       (?: \*= (?<value>.*)
+	         | \/= (?<delim>.) (?<value>.*?) \g{delim} (?=,|\z) ,*
+	         | (?: = (?<value> (?:[^,()]++ | ${paren_re})*+ ) )? ,* )
+	       /xgcs) {
+	    push @kv, ( $+{key}, $+{value} // 1 );
 	}
+	(pos() // 0) == length or die "parse error in \"$_\".\n";
     }
     @kv;
 }
@@ -202,8 +200,10 @@ Both will call the function as:
 
 Arguments are passed as I<key> =E<gt> I<value> pairs.  Parameters
 without a value (C<debug> in this example) are assigned the value 1.
-Key names may contain word characters (alphanumeric and underscore),
-hyphens, and dots.
+Key names should only contain word characters (C<\w>: alphanumeric and
+underscore).  Currently, any characters except C<,>, C<=>, C<*>, and
+C</> are accepted for historical reasons, but this may change in the
+future.
 
 Commas normally separate parameters.  If a value needs to contain
 commas, there are two ways to handle this:
@@ -222,20 +222,47 @@ This calls:
 
 Note that the parentheses are included in the value.
 
-=item Tilde
+=item Asterisk-Equals
 
-Use C<~> instead of C<=> to capture the entire remaining string as
+Use C<*=> instead of C<=> to capture the entire remaining string as
 the value:
 
-    func(debug,pattern~a,b,c)
+    func(debug,pattern*=a,b,c)
 
 This calls:
 
     func( debug => 1, pattern => 'a,b,c' );
 
-Since C<~> consumes the rest of the string, no parameters can follow
+Since C<*=> consumes the rest of the string, no parameters can follow
 it.
 
+=item Slash-Equals with Delimiter
+
+Use C</=> followed by a delimiter character to quote a value.  The
+first character after C</=> becomes the delimiter, and the value
+continues until the same delimiter appears again:
+
+    func(debug,pattern/=/a,b,c/,verbose)
+
+This calls:
+
+    func( debug => 1, pattern => 'a,b,c', verbose => 1 );
+
+The delimiter can be any character.  Choose one that does not appear
+in the value:
+
+    func(pattern/=/a,b,c/)         # / as delimiter
+    func(path/=|/usr/local/bin|)   # | as delimiter for paths
+    func(text/=:hello:world:)      # : as delimiter
+
+For scripting, control characters like BEL (C<\x07>) or US (C<\x1f>,
+Unit Separator) can be used as delimiters to avoid conflicts with any
+printable characters:
+
+    $delim = "\x07";   # BEL
+    $delim = "\x1f";   # US (Unit Separator)
+    $arg = "data/=${delim}any/chars=here,${delim}";
+
 =back
 
 An anonymous subroutine can also be specified inline:
